@@ -1057,6 +1057,7 @@ ruby_version_v3_0_x!(ruby_3_0_1);
 ruby_version_v3_0_x!(ruby_3_0_2);
 ruby_version_v3_0_x!(ruby_3_0_3);
 ruby_version_v3_1_x!(ruby_3_1_0);
+ruby_version_v3_1_x!(ruby_3_1_1);
 
 #[cfg(not(debug_assertions))]
 #[cfg(test)]
@@ -1518,4 +1519,21 @@ mod tests {
         .unwrap();
         assert_eq!(real_stack_trace_3_1_0(), stack_trace.trace);
     }
+
+    #[cfg(target_pointer_width = "64")]
+    #[test]
+    fn test_get_ruby_stack_trace_3_1_1() {
+        let source = coredump_3_1_0();
+        let vm_addr = 0x7f0dc0c83c58;
+        let global_symbols_addr = Some(0x7f0dc0c75e80);
+        let stack_trace = ruby_version::ruby_3_1_1::get_stack_trace::<CoreDump>(
+            0,
+            vm_addr,
+            global_symbols_addr,
+            &source,
+            0,
+        )
+        .unwrap();
+        assert_eq!(real_stack_trace_3_1_0(), stack_trace.trace);
+    }
 }
